@@ -15,9 +15,9 @@ from orm.fields import (
     Text,
     Time,
 )
-from orm.models import Model
+from orm.models import Model, ModelRegistry
 
-__version__ = "0.1.9"
+__version__ = "0.2.0"
 __all__ = [
     "NoMatch",
     "MultipleMatches",
@@ -36,4 +36,5 @@ __all__ = [
     "UUID",
     "ForeignKey",
     "Model",
+    "ModelRegistry",
 ]
